import requests
import shutil


class Photo:
    def __init__(self, path):
        self.path = path

    def download(self, site):
        response = requests.get(site)
        if response.status_code == 200:
            with open(self.path, 'wb') as file:
                response.raw.decode_content = True
                shutil.copyfileobj(response.raw, file)
            return True



import traceback
import sys
import os


def clear():
    if sys.platform in ('linux', 'linux2'):
        os.system('clear')
    elif sys.platform == 'win32':
        os.system('cls')
        print('\n')


def is_module(trace):
    if 'ModuleNotFoundError' in trace:
        module = trace.split("'")[1] if "'" in trace else None
        return module
    return None


def write_startfile(trace):
    with open('start_file.txt', 'w') as stfile:
        stfile.write(trace)
        stfile.close()


class InstallModuleError(Exception):
    """Static error class"""
    def __init__(self, message):
        super().__init__(message)


class AutoInstaller:
    def __init__(self):
        self.trace = traceback.format_exc()
        self.install()
        self.restart()

    def install(self):
        trace = self.trace
        if trace is not None:
            if is_module(trace):
                if os.path.exists('start_file.txt'):
                    last_traceback = open('start_file.txt', 'r').read()
                    if last_traceback == trace:
                        raise InstallModuleError(f"Can't install module named '{is_module(trace)}'")
                os.system(f"pip install {is_module(trace)}")
                write_startfile(trace)
                clear()

    def restart(self):
        trace = self.trace
        split = trace.split('\n')
        file = [i.split('"')[1] for i in split if 'File "' in i][0]
        os.system(f"python {file}")
        sys.exit()



from setuptools import setup
try:
    about = open('README.md', 'r').read()
except FileNotFoundError:
    about = None

setup(
    name='py-maia',
    version='1.5',
    description="Let's code better",
    packages=['maia', ],
    long_description=about,
    license='MIT',
    author='Arorior',
    url='https://github.com/Arorior/maia',
    long_description_content_type='text/markdown',
    include_package_data=True,
)



import time


def printr(text):
    print(text, end='\r')


class Loading:
    def __init__(self):
        pass

    @staticmethod
    def usual(xrange: dict):
        for i in xrange:
            if isinstance(i, int):
                yield str(i) + '%'
            raise ValueError

    @staticmethod
    def user_load(xrange: dict, desc='Object: %'):
        for x in xrange:
            try:
                yield desc.replace('%', x)
            except:
                raise ValueError
